(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     19142,        501]
NotebookOptionsPosition[     14908,        437]
NotebookOutlinePosition[     15389,        454]
CellTagsIndexPosition[     15346,        451]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Visualizing Molecules", "Subtitle",ExpressionUUID->"a57b32b3-422c-473e-be14-945003067cd7"],

Cell["\<\
This example makes use of data obtained from a third party website:
http://www.rcsb.org/pdb/cgi/explore.cgi?pid=22201112242025&page=0&pdbId=1A7F
\
\>", "Text",ExpressionUUID->"41242c52-b218-4bb4-9b35-199f16a820bf"],

Cell["First, we import the data as a table.", "Text",ExpressionUUID->"12485375-628c-4654-aeb2-03e6c6df4c0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8198876697994685`*^9, 3.8198876738453994`*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"0eacb944-2e6e-42b6-b931-339dd05ed455"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<1A7F.pdb\>\"", ",", "\"\<Table\>\""}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[94]:=",ExpressionUUID->"0588796c-ee25-492a-989b-7a5c3c53aa8f"],

Cell["Each row of interest has the following form.", "Text",ExpressionUUID->"3305e85c-1ed1-45b3-a11d-ab31dab43cc8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"[", "102", "]"}], "]"}]], "Input",
 CellLabel->"In[95]:=",ExpressionUUID->"4fe3f64f-88db-4299-b44e-fd22d49a3c35"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"ATOM\"\>", ",", "1", ",", "\<\"N\"\>", ",", "\<\"GLY\"\>", 
   ",", "\<\"A\"\>", ",", "1", ",", "0.074`", ",", "3.305`", ",", "12.661`", 
   ",", "1.`", ",", "0.`", ",", "\<\"N\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.387394872046875*^9, 3.8198876807503405`*^9},
 CellLabel->"Out[95]=",ExpressionUUID->"a57707eb-0fb2-42a9-8657-97c6f0533c6b"]
}, Open  ]],

Cell["\<\
The following extracts out only those rows containing atomic coordinates and \
types.\
\>", "Text",ExpressionUUID->"00f9a1bd-e3a4-41a1-b250-8c26ab905f56"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mol", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{"102", ",", "15238"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[96]:=",ExpressionUUID->"4b2d46cc-4ef2-4afb-9528-aac60660f868"],

Cell["\<\
Next, we trim the data to get only the coordinates and types, discarding the \
other information.\
\>", "Text",ExpressionUUID->"ea8a5b97-04dc-4e51-a510-df9849b5b0f7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"molcoords", "=", 
   RowBox[{"mol", "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "x_", 
       ",", "y_", ",", "z_", ",", "j_", ",", "k_", ",", "type_"}], "}"}], 
     "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z", ",", "type"}], "}"}]}]}]}], 
  ";"}]], "Input",
 CellLabel->"In[97]:=",ExpressionUUID->"a1b5b112-d577-42a0-985f-690c08076418"],

Cell["Here we can see the form of the remaining elements.", "Text",ExpressionUUID->"8ac23fcb-5da1-4a4a-af05-0a0aae89b58e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molcoords", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellLabel->"In[98]:=",ExpressionUUID->"e483906f-ecb5-43c4-865e-00db0133df98"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.074`", ",", "3.305`", ",", "12.661`", ",", "\<\"N\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.387394872265625*^9, 3.819887685046076*^9},
 CellLabel->"Out[98]=",ExpressionUUID->"3089f53e-3b6a-457e-be39-d65cbe0c1590"]
}, Open  ]],

Cell["For convenience, we define a scale factor.", "Text",ExpressionUUID->"795cf848-da85-415f-895b-6bb29e5a1ace"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scale", "=", ".8"}], ";"}]], "Input",
 CellChangeTimes->{
  3.38739502421875*^9, 3.38739506765625*^9, {3.387395103578125*^9, 
   3.387395105234375*^9}, {3.387395142328125*^9, 3.387395142375*^9}, {
   3.387395372640625*^9, 3.38739537271875*^9}},
 CellLabel->"In[99]:=",ExpressionUUID->"b10ba99d-058a-4308-9de5-fad10cb369ab"],

Cell["\<\
Next, we define colors and radii for sulfur, oxygen, nitrogen, carbon, and \
hydrogen, respectively.\
\>", "Text",
 CellChangeTimes->{{3.3873960803125*^9, 
  3.387396081984375*^9}},ExpressionUUID->"3740667f-285f-4bbb-94f4-\
ca6b34bcac97"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sc", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{".9", ",", ".7", ",", ".1"}], "]"}]}], ";", 
  RowBox[{"sr", "=", 
   RowBox[{"1.85", " ", "scale"}]}], ";"}]], "Input",
 CellChangeTimes->{3.387395388421875*^9},
 CellLabel->
  "In[100]:=",ExpressionUUID->"fd932505-73de-4916-87dc-065ea689f3c8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"oc", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"1", ",", ".1", ",", "0"}], "]"}]}], ";", 
  RowBox[{"or", "=", 
   RowBox[{"1.52", " ", "scale"}]}], ";"}]], "Input",
 CellChangeTimes->{3.38739539353125*^9},
 CellLabel->
  "In[101]:=",ExpressionUUID->"e961184b-feed-4007-a720-a4f3faaeb7f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nc", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{".2", ",", ".3", ",", ".9"}], "]"}]}], ";", 
  RowBox[{"nr", "=", 
   RowBox[{"1.55", " ", "scale"}]}], ";"}]], "Input",
 CellChangeTimes->{3.38739540103125*^9},
 CellLabel->
  "In[102]:=",ExpressionUUID->"799ddf86-d04a-4968-b8a9-c8e3013484a2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cc", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{".7", ",", ".7", ",", ".8"}], "]"}]}], ";", 
  RowBox[{"cr", "=", 
   RowBox[{"1.7", " ", "scale"}]}], ";"}]], "Input",
 CellChangeTimes->{3.38739540696875*^9},
 CellLabel->
  "In[103]:=",ExpressionUUID->"6b922ee1-1613-46fa-80eb-dcf0bcd9a329"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hc", "=", "White"}], ";", 
  RowBox[{"hr", "=", 
   RowBox[{"1.2", " ", "scale"}]}], ";"}]], "Input",
 CellChangeTimes->{3.3873954129375*^9},
 CellLabel->
  "In[104]:=",ExpressionUUID->"fad171fd-eaab-4334-a56a-c21a4e8b1f12"],

Cell["\<\
Now we isolate the different elements and apply the appropriate colors and \
radii.\
\>", "Text",ExpressionUUID->"67086560-b7f2-41e0-99df-c5bfd8e91f44"],

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "=", 
   RowBox[{"{", 
    RowBox[{"nc", ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Cases", "[", 
       RowBox[{"molcoords", ",", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x_", ",", "y_", ",", "z_", ",", "\"\<N\>\""}], "}"}], 
         "\[Rule]", 
         RowBox[{"Sphere", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "nr"}], "]"}]}], 
        ",", "Infinity"}], "]"}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.38739496009375*^9, 3.38739497209375*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"c3430e19-6976-49e4-aa71-e56ccfd6d6b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"o", "=", 
   RowBox[{"{", 
    RowBox[{"oc", ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Cases", "[", 
       RowBox[{"molcoords", ",", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x_", ",", "y_", ",", "z_", ",", "\"\<O\>\""}], "}"}], 
         "\[Rule]", 
         RowBox[{"Sphere", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "or"}], "]"}]}], 
        ",", "Infinity"}], "]"}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.387394977609375*^9, 3.387394979515625*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"1fd305de-59b5-4d18-b026-a780250fbc6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "=", 
   RowBox[{"{", 
    RowBox[{"hc", ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Cases", "[", 
       RowBox[{"molcoords", ",", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x_", ",", "y_", ",", "z_", ",", "\"\<H\>\""}], "}"}], 
         "\[Rule]", 
         RowBox[{"Sphere", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "hr"}], "]"}]}], 
        ",", "Infinity"}], "]"}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.38739498346875*^9, 3.3873949858125*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"e266592b-bc5e-4f4b-9554-065ee10a26b3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c", "=", 
   RowBox[{"{", 
    RowBox[{"cc", ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Cases", "[", 
       RowBox[{"molcoords", ",", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x_", ",", "y_", ",", "z_", ",", "\"\<C\>\""}], "}"}], 
         "\[Rule]", 
         RowBox[{"Sphere", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "cr"}], "]"}]}], 
        ",", "Infinity"}], "]"}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.387394990046875*^9, 3.387394992421875*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"380578f7-1076-4a20-b1bc-d19da02c333c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"s", "=", 
   RowBox[{"{", 
    RowBox[{"sc", ",", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Cases", "[", 
       RowBox[{"molcoords", ",", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x_", ",", "y_", ",", "z_", ",", "\"\<S\>\""}], "}"}], 
         "\[Rule]", 
         RowBox[{"Sphere", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "sr"}], "]"}]}], 
        ",", "Infinity"}], "]"}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.38739499571875*^9, 3.38739499771875*^9}},
 CellLabel->
  "In[109]:=",ExpressionUUID->"3ad6f1f2-eb53-452b-8b6f-016352e9d459"],

Cell["This particular dataset contains over 15,000 atoms.", "Text",ExpressionUUID->"9ae3cd81-e693-4ec5-89f4-f23b21307813"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"n", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}], "+", 
    RowBox[{"Length", "[", 
     RowBox[{"o", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}], "+", 
    RowBox[{"Length", "[", 
     RowBox[{"h", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}], "+", 
    RowBox[{"Length", "[", 
     RowBox[{"c", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}], "+", 
    RowBox[{"Length", "[", 
     RowBox[{"s", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ")"}], "/", "2"}]], "Input",
 CellLabel->
  "In[110]:=",ExpressionUUID->"1269d055-9ecd-4569-b949-dd4b81821186"],

Cell[BoxData["7530"], "Output",
 CellChangeTimes->{3.38739487746875*^9, 3.387395002765625*^9, 
  3.38739503959375*^9, 3.387395076125*^9, 3.387395110578125*^9, 
  3.387395146828125*^9, 3.387395432390625*^9, 3.8198877083133993`*^9},
 CellLabel->
  "Out[110]=",ExpressionUUID->"c93be198-30f5-4a02-99f1-dc39cffc50b1"]
}, Open  ]],

Cell["Finally, we can visualize the molecule.", "Text",ExpressionUUID->"97af7cd3-25fd-4a89-ba55-2893eab90cb7"],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Specularity", "[", 
      RowBox[{"White", ",", "50"}], "]"}], ",", "n", ",", "o", ",", "c", ",", 
     "s"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
   RowBox[{"Background", "\[Rule]", "Black"}], ",", 
   RowBox[{"Lighting", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<Ambient\>\"", ",", 
        RowBox[{"GrayLevel", "[", ".2", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Directional\>\"", ",", 
        RowBox[{"GrayLevel", "[", ".7", "]"}], ",", 
        RowBox[{"ImageScaled", "[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", " ", ",", "1"}], " ", "}"}], "]"}]}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.387395680484375*^9, 3.38739570121875*^9}, {
  3.38739576128125*^9, 3.387395771921875*^9}},
 CellLabel->
  "In[111]:=",ExpressionUUID->"07aee929-a5e8-454b-a522-c9533a2baa03"],

Cell["\<\
Here, we create an animation by rotating the camera around the molecule, just \
above the x-y plane.\
\>", "Text",ExpressionUUID->"0d0b8ea1-5fa0-4c2e-bc5f-7fbd03cfb14f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"anim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Graphics3D", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Specularity", "[", 
          RowBox[{"White", ",", "50"}], "]"}], ",", "n", ",", "o", ",", "c", 
         ",", "s"}], "}"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "200"}], ",", 
       RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
       RowBox[{"Background", "\[Rule]", "Black"}], ",", 
       RowBox[{"Lighting", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\"\<Ambient\>\"", ",", 
            RowBox[{"GrayLevel", "[", ".2", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\"\<Directional\>\"", ",", 
            RowBox[{"GrayLevel", "[", ".7", "]"}], ",", 
            RowBox[{"ImageScaled", "[", 
             RowBox[{"{", 
              RowBox[{"1", ",", "1", " ", ",", "1"}], " ", "}"}], "]"}]}], 
           "}"}]}], "}"}]}], ",", 
       RowBox[{"SphericalRegion", "\[Rule]", "True"}], ",", 
       RowBox[{"ViewPoint", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], ",", 
          RowBox[{"2", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}], ",", "0.5`"}], "}"}]}]}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", " ", "\[Pi]"}], ",", "0.1`"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.38739573515625*^9, 3.38739575271875*^9}, {
  3.387395784796875*^9, 3.387395795734375*^9}, {3.8198877180771275`*^9, 
  3.819887718171109*^9}},
 CellLabel->
  "In[112]:=",ExpressionUUID->"6fa6986b-d5ea-4826-8b1d-62e64523ff89"],

Cell["Here's the first frame of the animation.", "Text",ExpressionUUID->"50ed00c9-5da0-4409-b48c-9338adf71888"],

Cell["Now, we can export the animation.", "Text",ExpressionUUID->"c3c57d8a-156e-4e73-975f-369bd4c2496e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<insulin.mp4\>\"", ",", "anim"}], "]"}]], "Input",
 CellChangeTimes->{{3.387395863703125*^9, 3.387395872859375*^9}, {
  3.8198877240309553`*^9, 3.8198877258680534`*^9}},
 CellLabel->
  "In[113]:=",ExpressionUUID->"0bdbc4bc-989e-4e26-9ca3-7164735d6847"],

Cell[BoxData["\<\"insulin.mp4\"\>"], "Output",
 CellChangeTimes->{3.38739632884375*^9, 3.8198879841763*^9},
 CellLabel->
  "Out[113]=",ExpressionUUID->"2ea6ca6b-3b32-4224-8b0b-efa0c39834f9"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1108, 835},
WindowMargins->{{Automatic, 383}, {Automatic, 30}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"12.2 for Microsoft Windows (64-bit) (December 7, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"0c9bf732-a28a-4160-8a7f-37e53f2d0fdb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 96, 0, 53, "Subtitle",ExpressionUUID->"a57b32b3-422c-473e-be14-945003067cd7"],
Cell[666, 24, 224, 4, 78, "Text",ExpressionUUID->"41242c52-b218-4bb4-9b35-199f16a820bf"],
Cell[893, 30, 108, 0, 34, "Text",ExpressionUUID->"12485375-628c-4654-aeb2-03e6c6df4c0e"],
Cell[1004, 32, 272, 5, 28, "Input",ExpressionUUID->"0eacb944-2e6e-42b6-b931-339dd05ed455"],
Cell[1279, 39, 238, 6, 28, "Input",ExpressionUUID->"0588796c-ee25-492a-989b-7a5c3c53aa8f"],
Cell[1520, 47, 115, 0, 34, "Text",ExpressionUUID->"3305e85c-1ed1-45b3-a11d-ab31dab43cc8"],
Cell[CellGroupData[{
Cell[1660, 51, 161, 3, 28, "Input",ExpressionUUID->"4fe3f64f-88db-4299-b44e-fd22d49a3c35"],
Cell[1824, 56, 391, 6, 32, "Output",ExpressionUUID->"a57707eb-0fb2-42a9-8657-97c6f0533c6b"]
}, Open  ]],
Cell[2230, 65, 164, 3, 34, "Text",ExpressionUUID->"00f9a1bd-e3a4-41a1-b250-8c26ab905f56"],
Cell[2397, 70, 267, 7, 28, "Input",ExpressionUUID->"4b2d46cc-4ef2-4afb-9528-aac60660f868"],
Cell[2667, 79, 176, 3, 34, "Text",ExpressionUUID->"ea8a5b97-04dc-4e51-a510-df9849b5b0f7"],
Cell[2846, 84, 480, 13, 28, "Input",ExpressionUUID->"a1b5b112-d577-42a0-985f-690c08076418"],
Cell[3329, 99, 122, 0, 34, "Text",ExpressionUUID->"8ac23fcb-5da1-4a4a-af05-0a0aae89b58e"],
Cell[CellGroupData[{
Cell[3476, 103, 164, 3, 28, "Input",ExpressionUUID->"e483906f-ecb5-43c4-865e-00db0133df98"],
Cell[3643, 108, 263, 5, 32, "Output",ExpressionUUID->"3089f53e-3b6a-457e-be39-d65cbe0c1590"]
}, Open  ]],
Cell[3921, 116, 113, 0, 34, "Text",ExpressionUUID->"795cf848-da85-415f-895b-6bb29e5a1ace"],
Cell[4037, 118, 358, 7, 28, "Input",ExpressionUUID->"b10ba99d-058a-4308-9de5-fad10cb369ab"],
Cell[4398, 127, 248, 6, 34, "Text",ExpressionUUID->"3740667f-285f-4bbb-94f4-ca6b34bcac97"],
Cell[4649, 135, 332, 9, 28, "Input",ExpressionUUID->"fd932505-73de-4916-87dc-065ea689f3c8"],
Cell[4984, 146, 329, 9, 28, "Input",ExpressionUUID->"e961184b-feed-4007-a720-a4f3faaeb7f8"],
Cell[5316, 157, 331, 9, 28, "Input",ExpressionUUID->"799ddf86-d04a-4968-b8a9-c8e3013484a2"],
Cell[5650, 168, 330, 9, 28, "Input",ExpressionUUID->"6b922ee1-1613-46fa-80eb-dcf0bcd9a329"],
Cell[5983, 179, 259, 7, 28, "Input",ExpressionUUID->"fad171fd-eaab-4334-a56a-c21a4e8b1f12"],
Cell[6245, 188, 162, 3, 34, "Text",ExpressionUUID->"67086560-b7f2-41e0-99df-c5bfd8e91f44"],
Cell[6410, 193, 683, 19, 28, "Input",ExpressionUUID->"c3430e19-6976-49e4-aa71-e56ccfd6d6b0"],
Cell[7096, 214, 685, 19, 28, "Input",ExpressionUUID->"1fd305de-59b5-4d18-b026-a780250fbc6b"],
Cell[7784, 235, 682, 19, 28, "Input",ExpressionUUID->"e266592b-bc5e-4f4b-9554-065ee10a26b3"],
Cell[8469, 256, 685, 19, 28, "Input",ExpressionUUID->"380578f7-1076-4a20-b1bc-d19da02c333c"],
Cell[9157, 277, 683, 19, 28, "Input",ExpressionUUID->"3ad6f1f2-eb53-452b-8b6f-016352e9d459"],
Cell[9843, 298, 122, 0, 34, "Text",ExpressionUUID->"9ae3cd81-e693-4ec5-89f4-f23b21307813"],
Cell[CellGroupData[{
Cell[9990, 302, 674, 20, 28, "Input",ExpressionUUID->"1269d055-9ecd-4569-b949-dd4b81821186"],
Cell[10667, 324, 313, 5, 32, "Output",ExpressionUUID->"c93be198-30f5-4a02-99f1-dc39cffc50b1"]
}, Open  ]],
Cell[10995, 332, 110, 0, 34, "Text",ExpressionUUID->"97af7cd3-25fd-4a89-ba55-2893eab90cb7"],
Cell[11108, 334, 1107, 28, 48, "Input",ExpressionUUID->"07aee929-a5e8-454b-a522-c9533a2baa03"],
Cell[12218, 364, 179, 3, 34, "Text",ExpressionUUID->"0d0b8ea1-5fa0-4c2e-bc5f-7fbd03cfb14f"],
Cell[12400, 369, 1736, 45, 68, "Input",ExpressionUUID->"6fa6986b-d5ea-4826-8b1d-62e64523ff89"],
Cell[14139, 416, 111, 0, 34, "Text",ExpressionUUID->"50ed00c9-5da0-4409-b48c-9338adf71888"],
Cell[14253, 418, 104, 0, 34, "Text",ExpressionUUID->"c3c57d8a-156e-4e73-975f-369bd4c2496e"],
Cell[CellGroupData[{
Cell[14382, 422, 305, 6, 28, "Input",ExpressionUUID->"0bdbc4bc-989e-4e26-9ca3-7164735d6847"],
Cell[14690, 430, 190, 3, 32, "Output",ExpressionUUID->"2ea6ca6b-3b32-4224-8b0b-efa0c39834f9"]
}, Open  ]]
}, Open  ]]
}
]
*)

